/*********************** (c) STMicroelectronics *******************************

NAME:		io7265.h
PROJECT:	USB 7265 - ST7
VERSION:	v 1.00
CREATION:	21-FEB-2003
AUTHOR:		MICROCONTROLLER DIVISION / ST Rousset

-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-

DESCRIPTION : ST7265 Hardware Register Mapping.
              This file contains the description of the hardware register of
              the ST7265 IC. Variable forced to a fixed address.
              WARNING : this file is only for COSMIC compiler !

-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-
MODIFICATIONS :
******************************************************************************/

/* A PORT REGISTERS */
volatile char PADR @0x00;				/* PORT A : Data		*/
volatile char PADDR @0x01;			/* PORT A : Data Direction	*/
volatile char PAOR @0x02;				/* PORT A : Option Register	*/

/* B PORT REGISTERS */
volatile char PBDR @0x03;				/* PORT B : Data		*/
volatile char PBDDR @0x04;			/* PORT B : Data Direction	*/

/* C PORT REGISTERS */
volatile char PCDR @0x06;				/* PORT C : Data		*/
volatile char PCDDR @0x07;			/* PORT C : Data Direction	*/
volatile char PCOR @0x08;				/* PORT C : Option Register	*/

/* D PORT REGISTERS */
volatile char PDDR @0x09;				/* PORT D : Data		*/
volatile char PDDDR @0x0A;			/* PORT D : Data Direction	*/
volatile char PDOR @0x0B;				/* PORT D : Option Register	*/

/* E PORT REGISTERS */
volatile char PEDR @0x0C;				/* PORT E : Data		*/
volatile char PEDDR @0x0D;			/* PORT E : Data Direction	*/
volatile char PEOR @0x0E;				/* PORT E : Option Register	*/

/* F PORT REGISTERS */
volatile char PFDR @0x0F;					// PORT F : Data
volatile char PFDDR @0x10;				// Data Direction
volatile char PFOR @0x11;				// reserved area


/* A/D CONVERTER */
volatile char ADCDR @0x12;				// Data Register
volatile char ADCCSR @0x13;				// Control/Status Register

/* WATCHDOG */
volatile char WDGCR @0x14;				// Watchdog Control Register

/* DSM */
volatile char PCR @0x18;					// Power Control Register

/* SPI */
volatile char SPIDR @0x19;
volatile char SPICR @0x1A;
volatile char SPICSR @0x1B;

/* DTC */
volatile char DTCCTRL @0x1C;				// DTC Control Register
volatile char DTCSTATUS @0x1D;			// DTC Status Register
volatile char DTCCRC_RES @0x1E;			// Reserved DTC CRC Register
volatile char DTCPC @0x1F;				// DTC Program Counter Register

/* TIM */
volatile char TCR1 @0x20;				// timer control register 1
volatile char TCR2 @0x21;				// timer control register 2
volatile char TSR @0x22;				// timer status  register
volatile char CRH @0x23;				// timer counter H register (15:8)
volatile char CRL @0x24;				// timer counter L register (7:0)
volatile char CHRA @0x25;				// timer alternate counter H register (15:8)
volatile char CLRA @0x26;				// timer alternate counter L register (7:0)
volatile char OCHR1 @0x27;			// timer output compare H register 1
volatile char OCLR1 @0x28;			// timer output compare L register 1
volatile char OCHR2 @0x29;			// timer output compare H register 2
volatile char OCLR2 @0x2A;			// timer output compare L register 2

/* FLASH */
volatile char FCSR @0x2B;			// Flash control Status

/* SW ITC */
volatile char ITSPR0 @0x2C;			// Interrupt Software Priority Register 0
volatile char ITSPR1 @0x2D;			// Interrupt Software Priority Register 1
volatile char ITSPR2 @0x2E;			// Interrupt Software Priority Register 2
volatile char ITSPR3 @0x2F;			// Interrupt Software Priority Register 3

/* USB */
volatile char USBISTR @0x30;			// Interrupt StaTus Register
volatile char USBIMR @0x31;			// Interrupt Mask Register
volatile char USBCTLR @0x32;			// Control Register
volatile char DADDR @0x33;			// Device ADDress Register
volatile char USBSR @0x34;			// USB Status Register
volatile char EP0R @0x35;				// Endpoint 0 Register
volatile char CNT0RXR @0x36;			// CouNT endp. 0 Reception Registe
volatile char CNT0TXR @0x37;			// CouNT endp. 0 Reception Register
volatile char EP1RXR @0x38;			// Endpoint 1 Reception Register
volatile char CNT1RXR @0x39;			// CouNT endp. 1 Reception Register
volatile char EP1TXR @0x3A;			// Endpoint 1 Transmission Register
volatile char CNT1TXR @0x3B;			// CouNT endp. 1 Transmission Register
volatile char EP2RXR @0x3C;			// Endpoint 2 Reception Register
volatile char CNT2RXR @0x3D;			// CouNT endp. 2 Reception Register
volatile char EP2TXR @0x3E;			// Endpoint 2 Transmission Register
volatile char CNT2TXR @0x3F;			// CouNT endp. 2 Reception Register

/* I2C INTERFACE */
volatile char I2CCR @0x40;			// i2c control register
volatile char I2CSR1 @0x41;			// i2c status register 1
volatile char I2CSR2 @0x42;			// i2c status register 2
volatile char I2CCCR @0x43;			// i2c clock control register
volatile char I2COAR1 @0x44;			// i2c own address register 1
volatile char I2COAR2 @0x45;			// i2c own address register 2
volatile char I2CDR @0x46;			// i2c data register

/* USB */
volatile char BUFSR @0x47;			// Buffer Manager status register

/* MISCELLANEOUS */
volatile char MISCR1 @0x49;			// Miscellaneous Register 1
volatile char MISCR2 @0x4A;			// Miscellaneous Register 2
volatile char MISCR_RES @0x4B;		// Reserved Miscellaneous Register
volatile char MISCR3 @0x4C;			// Miscellaneous Register 3

/* PWM */
volatile char PWM0 @0x4D;				// pbm: PWM 0 register
volatile char BRM10 @0x4E;			// pbm: BRM 0 register ( for 4bit brm0 and brm1 )
volatile char PWM1 @0x4F;				// pbm: PWM 1 register

volatile char EP0_OUT[16] @0x1550;		// Map user variables in USB DATA BUFFERS.

volatile char EP0_IN[16] @0x1560;

volatile char EP1_OUT[16] @0x1570;

volatile char EP1_IN[16] @0x1580;

volatile char EP2_OUT[64] @0x1590;

volatile char EP2_IN[64] @0x15D0;

/********************************************/
/*					Buffer 0				*/
/********************************************/
	// Map user variables in BUFFER.
volatile char Buffer_0[512] @0x1650;	// RAM BUFFER 

/********************************************/
/*					Buffer 1				*/
/********************************************/
	// Map user variables in BUFFER.
volatile char Buffer_1[512] @0x1850;	// RAM BUFFER

/*** EOF ***/