/*********************** (c) STMicroelectronics *******************************

NAME:		io7hub.h
PROJECT:	USB HUB - ST7
VERSION:	v 1.00
CREATION:	20-FEB-2003
AUTHOR:		MICROCONTROLLER DIVISION / ST Rousset

-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-

DESCRIPTION : ST7HUB Hardware Register Mapping.
              This file contains the description of the hardware register of
              the ST7HUB IC. Variable forced to a fixed address.
              WARNING : this file is only for COSMIC compiler !

-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-
MODIFICATIONS :
******************************************************************************/

/* A PORT REGISTERS */
volatile char PADR @0x00;				/* PORT A : Data		*/
volatile char PADDR @0x01;			/* PORT A : Data Direction	*/
volatile char PAOR @0x02;				/* PORT A : Option Register	*/

/* B PORT REGISTERS */
volatile char PBDR @0x03;				/* PORT B : Data		*/
volatile char PBDDR @0x04;			/* PORT B : Data Direction	*/
volatile char PBOR @0x05;				/* PORT B : Option Register	*/

/* C PORT REGISTERS */
volatile char PCDR @0x006;				/* PORT C : Data		*/
volatile char PCDDR @0x07;			/* PORT C : Data Direction	*/
volatile char PCOR @0x08;				/* PORT C : Option Register	*/

/* D PORT REGISTERS */
volatile char PDDR @0x09;				/* PORT D : Data		*/
volatile char PDDDR @0x0A;			/* PORT D : Data Direction	*/
volatile char PDOR @0x0B;				/* PORT D : Option Register	*/

/* E PORT REGISTERS */
volatile char PEDR @0x0C;				/* PORT E : Data		*/
volatile char PEDDR @0x0D;			/* PORT E : Data Direction	*/
volatile char PEOR @0x0E;				/* PORT E : Option Register	*/

/* ITC REGISTERS */
volatile char ITRFREC @0x0F;
volatile char ITRFRED @0x10;
volatile char ITRFREE @0x11;

/* MISCELLANEOUS */
volatile char MISCR1 @0x12;			/* Miscellaneous Register 1	*/
volatile char MISCR2 @0x13;			/* Miscellaneous Register 2	*/

/* ADC REGISTERS */
volatile char ADCDRMSB @0x14;			/* ADC data register (bits 9:2)	*/
volatile char ADCDRLSB @0x15;			/* ADC data register (bits 1:0)	*/
volatile char ADCCSR @0x16;			/* ADC control status register	*/

/* WATCHDOG */
volatile char WDGCR @0x17;			/* Watchdog Control Register */

/* SPI REGISTERS */
volatile char SPIDR @0x19;			/* SPI Data	register	*/
volatile char SPICR @0x1A;			/* SPI control register	*/
volatile char SPICSR @0x1B;			/* SPI control status register	*/

/* PWM ART REGISTERS */
volatile char PWMDCR1 @0x1C;			/* PWM AR Timer Duty Cycle Register 1	*/
volatile char PWMDCR0 @0x1D;			/* PWM AR Timer Duty Cycle Register 0	*/
volatile char PWMCR @0x1E;			/* PWM AR Timer Control Register	*/
volatile char ARTCSR @0x1F;			/* Auto Reload Timer Control/Status Register	*/
volatile char ARTCAR @0x20;			/* Auto Reload Timer Counter Access Register	*/
volatile char ARTARR @0x21;			/* Auto Reload Timer Auto Reload Register	*/
volatile char ARTICCSR @0x22;			/* ART Input Capture Control/Status Register	*/
volatile char ARTICR1 @0x23;			/* ART Input Capture Register 1	*/
volatile char ARTICR2 @0x24;			/* ART Input Capture Register 2	*/

/* USB REGISTERS */
volatile char USBISTR @0x25;			/* USB Interrupt Status register	*/
volatile char USBIMR @0x26;			/* USB Interrupt Mask register	*/
volatile char USBCTLR @0x27;			/* USB Control register	*/
volatile char DADDR @0x28;			/* Device Address register	*/
volatile char USBSR @0x29;			/* USB Status register	*/
volatile char EP0R @0x2A;				/* Endpoint 0 Register */
volatile char CNT0RXR @0x2B;			/* CouNT endp. 0 Reception Register */
volatile char CNT0TXR @0x2C;			/* CouNT endp. 0 Reception Register */
volatile char EP1TXR @0x2D;			/* Endpoint 1 Transmission Register */
volatile char CNT1TXR @0x2E;			/* CouNT endp. 1 Transmission Register */
volatile char EP2RXR @0x2F;			/* Endpoint 2 Reception Register */
volatile char CNT2RXR @0x30;			/* CouNT endp. 2 Reception Register */
volatile char EP2TXR @0x31;			/* Endpoint 2 Transmission Register */
volatile char CNT2TXR @0x32;			/* CouNT endp. 2 Reception Register */
volatile char EP3TXR @0x33;			/* Endpoint 3 Transmission Register */
volatile char CNT3TXR @0x34;			/* CouNT endp. 3 Transmission Register */
volatile char EP4TXR @0x35;			/* Endpoint 4 Transmission Register */
volatile char CNT4TXR @0x36;			/* CouNT endp. 4 Transmission Register */
volatile char EP5TXR @0x37;			/* Endpoint 5 Transmission Register */
volatile char CNT5TXR @0x38;			/* CouNT endp. 5 Transmission Register */
volatile char ERRSR @0x39;

/* SW ITC */
volatile char ITSPR0 @0x3E;			/* Interrupt Software Priority Register 0 */
volatile char ITSPR1 @0x3F;			/* Interrupt Software Priority Register 1 */
volatile char ITSPR2 @0x40;			/* Interrupt Software Priority Register 2 */
volatile char ITSPR3 @0x41;			/* Interrupt Software Priority Register 3 */

/* TBU */
volatile char TBUCV @0x42;
volatile char TBUCSR @0x43;

/* FLASH */
volatile char FCSR @0x44;

/* HUB REGISTERS */
volatile char HUBCR @0x45;			/* HUB Control register	*/
volatile char HUBVIDLR @0x46;			/* HUB Vendor ID Low register	*/
volatile char HUBVIDHR @0x47;			/* HUB Vendor ID High register	*/
volatile char HUBPIDLR @0x48;			/* HUB Product ID Low register	*/
volatile char HUBPIDHR @0x49;			/* HUB Product ID High register	*/

/* ICD REGISTERS */
volatile char ICDCR @0x4A;			/* In Circuit Debug Control register	*/
volatile char ICDSR @0x4B;			/* ICD Status register	*/
volatile char ICDBK1H @0x4C;			/* ICD Breakpoint 1 MSB	*/
volatile char ICDBK1L @0x4D;			/* ICD Breakpoint 1 LSB	*/
volatile char ICDBK2H @0x4E;			/* ICD Breakpoint 2 MSB	*/
volatile char ICDBK2L @0x4F;			/* ICD Breakpoint 2 LSB	*/

volatile char EP0_OUT[8] @0x02A0;
volatile char EP0_IN[8] @0x02A8;
volatile char EP1_IN[8] @0x02B0;
volatile char EP2_OUT[64] @0x02B8;
volatile char EP2_IN[64] @0x02F8;
volatile char EP3_IN[8] @0x0338;
volatile char EP4_IN[8] @0x0340;
volatile char EP5_IN[8] @0x0348;

/*** EOF ***/