/*********************** (c) STMicroelectronics *******************************

NAME:		io7hub.h
PROJECT:	USB SCR - ST7
VERSION:	v 1.00
CREATION:	20-FEB-2003
AUTHOR:		MICROCONTROLLER DIVISION / ST Rousset

-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-

DESCRIPTION : ST7HUB Hardware Register Mapping.
              This file contains the description of the hardware register of
              the ST7HUB IC. Variable forced to a fixed address.
              WARNING : this file is only for COSMIC compiler !

-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-
MODIFICATIONS :
******************************************************************************/

/* A PORT REGISTERS */
volatile char PADR @0x11;                             /* PORT A : Data	 */
volatile char PADDR @0x12;                            /* Data Direction */
volatile char PAOR @0x13;                             /* PORT A : OR	 */

/* B PORT REGISTERS */
volatile char PBDR @0x15;                              /* PORT B : Data */
volatile char PBDDR @0x16;                             /* Data Direction*/
                        
/* C PORT REGISTERS */
volatile char PCDR @0x18;                              /* PORT C : Data */

/* D PORT REGISTERS */
volatile char PDDR @0x19;                              /* PORT D : Data  */
volatile char PDDDR @0x1A;                             /* Data Direction */
volatile char PDOR @0x1B;                             /* PORT D : OR	  */      

/* ISO UART REGISTERS */
volatile char SCICR @0x00;
volatile char SCISR @0x01;
volatile char SCCR @0x02;
volatile char SCETU @0x03;
volatile char SCE1 @0x04;
volatile char GT0 @0x05;
volatile char GT1 @0x06;
volatile char CWT0 @0x07;
volatile char CWT1 @0x08;
volatile char CWT2 @0x09;
volatile char IC @0xA;
volatile char IS @0xB;
volatile char TB @0xC;
volatile char RB @0xD;

/* WATCHDOG */
volatile char WDGCR @0xE;                             /* Watchdog Control Register */     

/* MISCELLANEOUS */
volatile char MISCR1 @0x1C;                           /* Miscellaneous Register 1	*/
volatile char MISCR2 @0x1D;                           /* Miscellaneous Register 2	*/
volatile char MISCR3 @0x1E;                     	/* Miscellaneous Register 3	*/
volatile char MISCR4 @0x1F;                           /* Miscellaneous Register 4	*/

/* USB */
volatile char USBISTR @0x20;                              /* Interrupt StaTus Register*/
volatile char USBIMR @0x21;                               /* Interrupt Mask Register */
volatile char USBCTLR @0x22;                              /* Control Register */
volatile char DADDR @0x23;                             /* Device ADDress Register */
volatile char USBSR @0x24;                             /* USB Status Register */
volatile char EP0R @0x25;                              /* Endpoint 0 Register */
volatile char CNT0RXR @0x26;                           /* CouNT endp. 0 Reception Register */
volatile char CNT0TXR @0x27;                           /* CouNT endp. 0 Reception Register */
volatile char EP1TXR @0x28;                            /* Endpoint 1 Transmission Register */
volatile char CNT1TXR @0x29;                           /* CouNT endp. 1 Transmission Register */
volatile char EP2RXR @0x2A;                            /* Endpoint 2 Reception Register */
volatile char CNT2RXR @0x2B;                           /* CouNT endp. 2 Reception Register */
volatile char EP2TXR @0x2C;                            /* Endpoint 2 Transmission Register */
volatile char CNT2TXR @0x2D;                           /* CouNT endp. 2 Reception Register */
volatile char EP3TXR @0x2E;                            /* Endpoint 3 Transmission Register */
volatile char CNT3TXR @0x2F;                           /* CouNT endp. 3 Transmission Register */
volatile char EP4TXR @0x30;                            /* Endpoint 4 Transmission Register */
volatile char CNT4TXR @0x31;                           /* CouNT endp. 4 Transmission Register */
volatile char EP5TXR @0x32;                            /* Endpoint 5 Transmission Register */
volatile char CNT5TXR @0x33;                           /* CouNT endp. 5 Transmission Register */

/* TBU */
volatile char TBUCV @0x35;
volatile char TBUCSR @0x36;

/* SW ITC */
volatile char ITSPR0 @0x37;                              /* Interrupt Software Priority Register 0 **modified */
volatile char ITSPR1 @0x38;                              /* Interrupt Software Priority Register 1 **modified */
volatile char ITSPR2 @0x39;                              /* Interrupt Software Priority Register 2 **modified */
volatile char ITSPR3 @0x3A;                              /* Interrupt Software Priority Register 3 **modified */

volatile char USB_OBSR1 @0x3B;
volatile char USB_OBSR2 @0x3C;

volatile char LED_CTRL @0x3E; 

volatile char EP0_OUT[8] @0x240;

volatile char EP0_IN[8] @0x248;  

volatile char EP1_IN[8] @0x250;

volatile char EP2_OUT[64] @0x258;

volatile char EP2_IN[64] @0x298;

volatile char EP3_IN[8] @0x2D8;

volatile char EP4_IN[8] @0x2E0;

volatile char EP5_IN[8] @0x2E8;


/*** EOF ***/