#***(c) STMicroelectronics ****************************************************
#
# PROJECT : ST7 USB FULL SPEED
#
# COMPILER : COSMIC
#
# VERSION : 1.10
#
# DESCRIPTION : Make file for the ST72652
#
#******************************************************************************

#*** PROJECT, PRODUCT AND PROGRAM MEMORY DEFINITION ***

# Here declare your product name, size and start of the Program Memory 
PROJECT  = USB_FS
PRODUCT  = 7265
SIZE = 32K
PROG_MEM = 0x8000

#*** PATHS DEFINITION ***

# Here you declare where you store the different tools
TOOLS_PATH = C:\Cosmic\St7

# Here you declare where you store your project sources
PRJ_PATH = D:\Vss\ST7USBFS-Library\Work

#*** SUB PATHS DEFINITION ***

CNF_PATH  = $(PRJ_PATH)\Config\Cosmic
OBJ_PATH  = $(PRJ_PATH)\Object\Cosmic
SRC_PATH  = $(PRJ_PATH)\Sources
USB_PATH  = $(PRJ_PATH)\Sources\Usb
USER_PATH = $(PRJ_PATH)\Sources\User

#*** I/O FILES DEFINITION ***

LKF_FILE = $(CNF_PATH)\$(PROJECT)_$(PRODUCT)_$(SIZE).lkf
MAK_FILE = $(CNF_PATH)\$(PROJECT)_$(PRODUCT)_$(SIZE).mak

ST7_FILE = $(OBJ_PATH)\$(PROJECT)_$(PRODUCT)_$(SIZE).st7
ELF_FILE = $(OBJ_PATH)\$(PROJECT)_$(PRODUCT)_$(SIZE).elf
S19_FILE = $(OBJ_PATH)\$(PROJECT)_$(PRODUCT)_$(SIZE).s19
MAP_FILE = $(OBJ_PATH)\$(PROJECT)_$(PRODUCT).map
 
#*** COMMANDS DEFINITION ***

# Here you declare which tool will be used : C Compiler, Assembler, Linker, etc...
COMP = $(TOOLS_PATH)\cxst7.exe 
ASM  = $(TOOLS_PATH)\cast7.exe
LINK = $(TOOLS_PATH)\clnk.exe
CONV = $(TOOLS_PATH)\cvdwarf.exe
CHEX = $(TOOLS_PATH)\chex.exe

# Here you declare which options are to be used by the different tools
# To be used for uncrypted sources
CFLAGS  = +modms +debug -pad +split -l -co $(OBJ_PATH) -i $(SRC_PATH) -i $(USB_PATH) -i $(USER_PATH) -i $(CNF_PATH)
AFLAGS  = -xx -l -v
LFLAGS  = -o $(ST7_FILE) -m $(MAP_FILE) -v -sa
HFLAGS  = -e $(PROG_MEM) -o $(S19_FILE)

# Commands set-up
CC  = $(COMP) $(CFLAGS)
CCY = $(COMP) $(CFLAGSY)
AS  = $(ASM) $(AFLAGS)
LK  = $(LINK) $(LFLAGS)
CV  = $(CONV)
HX  = $(CHEX) $(HFLAGS)

#*** OBJECT FILES DEFINITION ***

# Here you define all the application objects and their location
OBJ_LIST = $(OBJ_PATH)\usb_lib.o $(OBJ_PATH)\usb_int.o $(OBJ_PATH)\usb_ep1.o $(OBJ_PATH)\usb_ep2.o $(OBJ_PATH)\usb_eps.o \
	$(OBJ_PATH)\main.o $(OBJ_PATH)\application.o $(OBJ_PATH)\descriptor.o $(OBJ_PATH)\user_usb.o \
	$(OBJ_PATH)\Vect_$(PRODUCT).o

#*** EPB FILE CREATION ***

# Here, Conversion from COSMIC format (.ST7) to Hexadecimal format (.S19) for EPB
$(S19_FILE): $(ELF_FILE)
	$(HX) $(ST7_FILE)
             
#*** COSMIC TO STVD7 CONVERSION ***
             
# Here, Conversion from COSMIC format (.ST7) to STVD7 format (.ELF)
$(ELF_FILE): $(ST7_FILE)
	$(CV) $(ST7_FILE)
        
#*** LINKING ***  
        
# Here, all the object files are linked all together to create a .ST7 file 
$(ST7_FILE): $(OBJ_LIST)
	$(LK) $(LKF_FILE) 	      

#*** COMPILATION ***

#------------------
# CONFIG DIRECTORY
#------------------

$(OBJ_PATH)\Vect_$(PRODUCT).o: $(CNF_PATH)\Vect_$(PRODUCT).c
	$(CC) $(CNF_PATH)\Vect_$(PRODUCT).c

#---------------
# USB DIRECTORY
#---------------

$(OBJ_PATH)\usb_ep1.o: $(USB_PATH)\usb_ep1.c
	$(CC) $(USB_PATH)\usb_ep1.c
	
$(OBJ_PATH)\usb_ep2.o: $(USB_PATH)\usb_ep2.c
	$(CC) $(USB_PATH)\usb_ep2.c

$(OBJ_PATH)\usb_eps.o: $(USB_PATH)\usb_eps.c
	$(CC) $(USB_PATH)\usb_eps.c

$(OBJ_PATH)\usb_int.o: $(USB_PATH)\usb_int.c
	$(CC) $(USB_PATH)\usb_int.c

$(OBJ_PATH)\usb_lib.o: $(USB_PATH)\usb_lib.c
	$(CC) $(USB_PATH)\usb_lib.c

#-----------------
# SOURCE DIRECTORY
#-----------------

$(OBJ_PATH)\main.o: $(SRC_PATH)\main.c
	$(CC) $(SRC_PATH)\main.c

#----------------
# USER DIRECTORY
#----------------

$(OBJ_PATH)\application.o: $(USER_PATH)\application.c
	$(CC) $(USER_PATH)\application.c

$(OBJ_PATH)\descriptor.o: $(USER_PATH)\descriptor.c
	$(CC) $(USER_PATH)\descriptor.c

$(OBJ_PATH)\user_usb.o: $(USER_PATH)\user_usb.c
	$(CC) $(USER_PATH)\user_usb.c
      
#*** COMMANDS CALLED BEFORE 'REBUILD ALL' PROCESS ***
      
clean :                         
	del $(OBJ_PATH)\*.o
	del $(OBJ_PATH)\*.st7
	del $(OBJ_PATH)\*.elf
	del $(OBJ_PATH)\*.s19
	del $(OBJ_PATH)\*.ls
	del $(OBJ_PATH)\*.lst
	del $(OBJ_PATH)\*.map
	$(MAKE) -f $(MAK_FILE)
	
#*** END OF FILE ***