/**************** (c) 2001  STMicroelectronics *******************************

NAME:		map_7hub.c
PROJECT:	USB HUB - ST7
VERSION:	v 1.00
CREATION:	27/11/2001
AUTHOR:		MICROCONTROLLER DIVISION / ST Rousset

-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-

DESCRIPTION : ST7HUB Hardware Register Mapping.
              This file contains the description of the hardware register of
              the ST7HUB IC. Variable forced to a fixed address.
              WARNING : this file need a specific LINKER configuration file !
-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-
MODIFICATIONS :
******************************************************************************/
#include "map_7hub.h"

/********************************************/
/*	                 HW Reg             */
/********************************************/
/* A PORT REGISTERS */
#pragma DATA_SEG SHORT PORTA
volatile char PADR;				/* PORT A : Data		*/
volatile char PADDR;			/* PORT A : Data Direction	*/
volatile char PAOR;				/* PORT A : Option Register	*/

/* B PORT REGISTERS */
#pragma DATA_SEG SHORT PORTB
volatile char PBDR;				/* PORT B : Data		*/
volatile char PBDDR;			/* PORT B : Data Direction	*/
volatile char PBOR;				/* PORT B : Option Register	*/

/* C PORT REGISTERS */
#pragma DATA_SEG SHORT PORTC
volatile char PCDR;				/* PORT C : Data		*/
volatile char PCDDR;			/* PORT C : Data Direction	*/
volatile char PCOR;				/* PORT C : Option Register	*/

/* D PORT REGISTERS */
#pragma DATA_SEG SHORT PORTD
volatile char PDDR;				/* PORT D : Data		*/
volatile char PDDDR;			/* PORT D : Data Direction	*/
volatile char PDOR;				/* PORT D : Option Register	*/

/* E PORT REGISTERS */
#pragma DATA_SEG SHORT PORTE
volatile char PEDR;				/* PORT E : Data		*/
volatile char PEDDR;			/* PORT E : Data Direction	*/
volatile char PEOR;				/* PORT E : Option Register	*/

/* ITC REGISTERS */
#pragma DATA_SEG SHORT ITC1
volatile char ITRFREC;
volatile char ITRFRED;
volatile char ITRFREE;

/* MISCELLANEOUS */
#pragma DATA_SEG SHORT MISCR
volatile char MISCR1;			/* Miscellaneous Register 1	*/
volatile char MISCR2;			/* Miscellaneous Register 2	*/

/* ADC REGISTERS */
#pragma DATA_SEG SHORT ADC
volatile char ADCDRMSB;			/* ADC data register (bits 9:2)	*/
volatile char ADCDRLSB;			/* ADC data register (bits 1:0)	*/
volatile char ADCCSR;			/* ADC control status register	*/

/* WATCHDOG */
#pragma DATA_SEG SHORT WATCHDOG
volatile char WDGCR;			/* Watchdog Control Register */

/* SPI REGISTERS */
#pragma DATA_SEG SHORT SPI
volatile char SPIDR;			/* SPI Data	register	*/
volatile char SPICR;			/* SPI control register	*/
volatile char SPICSR;			/* SPI control status register	*/

/* PWM ART REGISTERS */
#pragma DATA_SEG SHORT ART
volatile char PWMDCR1;			/* PWM AR Timer Duty Cycle Register 1	*/
volatile char PWMDCR0;			/* PWM AR Timer Duty Cycle Register 0	*/
volatile char PWMCR;			/* PWM AR Timer Control Register	*/
volatile char ARTCSR;			/* Auto Reload Timer Control/Status Register	*/
volatile char ARTCAR;			/* Auto Reload Timer Counter Access Register	*/
volatile char ARTARR;			/* Auto Reload Timer Auto Reload Register	*/
volatile char ARTICCSR;			/* ART Input Capture Control/Status Register	*/
volatile char ARTICR1;			/* ART Input Capture Register 1	*/
volatile char ARTICR2;			/* ART Input Capture Register 2	*/

/* USB REGISTERS */
#pragma DATA_SEG SHORT USB
volatile char USBISTR;			/* USB Interrupt Status register	*/
volatile char USBIMR;			/* USB Interrupt Mask register	*/
volatile char USBCTLR;			/* USB Control register	*/
volatile char DADDR;			/* Device Address register	*/
volatile char USBSR;			/* USB Status register	*/
volatile char EP0R;				/* Endpoint 0 Register */
volatile char CNT0RXR;			/* CouNT endp. 0 Reception Register */
volatile char CNT0TXR;			/* CouNT endp. 0 Reception Register */
volatile char EP1TXR;			/* Endpoint 1 Transmission Register */
volatile char CNT1TXR;			/* CouNT endp. 1 Transmission Register */
volatile char EP2RXR;			/* Endpoint 2 Reception Register */
volatile char CNT2RXR;			/* CouNT endp. 2 Reception Register */
volatile char EP2TXR;			/* Endpoint 2 Transmission Register */
volatile char CNT2TXR;			/* CouNT endp. 2 Reception Register */
volatile char EP3TXR;			/* Endpoint 3 Transmission Register */
volatile char CNT3TXR;			/* CouNT endp. 3 Transmission Register */
volatile char EP4TXR;			/* Endpoint 4 Transmission Register */
volatile char CNT4TXR;			/* CouNT endp. 4 Transmission Register */
volatile char EP5TXR;			/* Endpoint 5 Transmission Register */
volatile char CNT5TXR;			/* CouNT endp. 5 Transmission Register */
volatile char ERRSR;

/* SW ITC */
#pragma DATA_SEG SHORT ITC2
volatile char ITSPR0;			/* Interrupt Software Priority Register 0 */
volatile char ITSPR1;			/* Interrupt Software Priority Register 1 */
volatile char ITSPR2;			/* Interrupt Software Priority Register 2 */
volatile char ITSPR3;			/* Interrupt Software Priority Register 3 */

/* TBU */
#pragma DATA_SEG SHORT TBU
volatile char TBUCV;
volatile char TBUCSR;

/* FLASH */
#pragma DATA_SEG SHORT FLASH
volatile char FCSR;

/* HUB REGISTERS */
#pragma DATA_SEG SHORT HUB
volatile char HUBCR;			/* HUB Control register	*/
volatile char HUBVIDLR;			/* HUB Vendor ID Low register	*/
volatile char HUBVIDHR;			/* HUB Vendor ID High register	*/
volatile char HUBPIDLR;			/* HUB Product ID Low register	*/
volatile char HUBPIDHR;			/* HUB Product ID High register	*/

/* ICD REGISTERS */
#pragma DATA_SEG SHORT ICD
volatile char ICDCR;			/* In Circuit Debug Control register	*/
volatile char ICDSR;			/* ICD Status register	*/
volatile char ICDBK1H;			/* ICD Breakpoint 1 MSB	*/
volatile char ICDBK1L;			/* ICD Breakpoint 1 LSB	*/
volatile char ICDBK2H;			/* ICD Breakpoint 2 MSB	*/
volatile char ICDBK2L;			/* ICD Breakpoint 2 LSB	*/


#pragma DATA_SEG EP0_OUT
volatile char EP0_OUT[8];

#pragma DATA_SEG EP0_IN
volatile char EP0_IN[8];

#pragma DATA_SEG EP1_IN
volatile char EP1_IN[8];

#pragma DATA_SEG EP2_OUT
volatile char EP2_OUT[64];

#pragma DATA_SEG EP2_IN
volatile char EP2_IN[64];

#pragma DATA_SEG EP3_IN
volatile char EP3_IN[8];

#pragma DATA_SEG EP4_IN
volatile char EP4_IN[8];

#pragma DATA_SEG EP5_IN
volatile char EP5_IN[8];



#pragma DATA_SEG DEFAULT_RAM

/*** (c) 2001   STMicroelectronics ****************** END OF FILE ***/