/**************** (c) 2001  STMicroelectronics **********************

PROJECT:	USB HUB - ST7
VERSION:	v 1.0
CREATION:	27/01/2001
AUTHOR:		MICROCONTROLLER DIVISION / ST Rousset

-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-

DESCRIPTION : ST7HUB Hardware Register Mapping.
              This file contains the description of the hardware register of
              the ST7HUB IC. Variable forced to a fixed address.
              WARNING : this file need a specific LINKER configuration file !
-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-
MODIFICATIONS :
******************************************************************************/

#ifndef MAP_ST7HUB_H
#define MAP_ST7HUB_H

/********************************************/
/*	                 HW Reg             */
/********************************************/
/* A PORT REGISTERS */
#pragma DATA_SEG SHORT PORTA
extern volatile char PADR;				/* PORT A : Data		*/
extern volatile char PADDR;			/* PORT A : Data Direction	*/
extern volatile char PAOR;				/* PORT A : Option Register	*/

/* B PORT REGISTERS */
#pragma DATA_SEG SHORT PORTB
extern volatile char PBDR;				/* PORT B : Data		*/
extern volatile char PBDDR;			/* PORT B : Data Direction	*/
extern volatile char PBOR;				/* PORT B : Option Register	*/

/* C PORT REGISTERS */
#pragma DATA_SEG SHORT PORTC
extern volatile char PCDR;				/* PORT C : Data		*/
extern volatile char PCDDR;			/* PORT C : Data Direction	*/
extern volatile char PCOR;				/* PORT C : Option Register	*/

/* D PORT REGISTERS */
#pragma DATA_SEG SHORT PORTD
extern volatile char PDDR;				/* PORT D : Data		*/
extern volatile char PDDDR;			/* PORT D : Data Direction	*/
extern volatile char PDOR;				/* PORT D : Option Register	*/

/* E PORT REGISTERS */
#pragma DATA_SEG SHORT PORTE
extern volatile char PEDR;				/* PORT E : Data		*/
extern volatile char PEDDR;			/* PORT E : Data Direction	*/
extern volatile char PEOR;				/* PORT E : Option Register	*/

/* ITC REGISTERS */
#pragma DATA_SEG SHORT ITC
extern volatile char ITRFREC;
extern volatile char ITRFRED;
extern volatile char ITRFREE;

/* MISCELLANEOUS */
#pragma DATA_SEG SHORT MISCR
extern volatile char MISCR1;			/* Miscellaneous Register 1	*/
	#define		IS01		0x80
	#define		IS00		0x40
	#define		IS11		0x20
	#define		IS10		0x10
	#define		IS21		0x08
	#define		IS20		0x04
	#define		MCO			0x02
	#define		CSEL		0x01
extern volatile char MISCR2;			/* Miscellaneous Register 2	*/
	#define		PACK1		0x80
	#define		PACK0		0x40
	#define		ADSTS		0x10
	#define		ADIE		0x08
	#define		PE0DPU		0x04
	#define		PBODPU		0x02
	#define		PAODPU		0x01


/* ADC REGISTERS */
#pragma DATA_SEG SHORT ADC
extern volatile char ADCDRMSB;			/* ADC data register (bits 9:2)	*/
extern volatile char ADCDRLSB;			/* ADC data register (bits 1:0)	*/
extern volatile char ADCCSR;			/* ADC control status register	*/
	#define		EOC			0x80
	#define		PRSC1		0x40
	#define		PRSC0		0x20
	#define		ADON		0x10
	#define		CS3			0x08
	#define		CS2			0x04
	#define		CS1			0x02
	#define		CS0			0x01

/* WATCHDOG */
#pragma DATA_SEG SHORT WATCHDOG
extern volatile char WDGCR;			/* Watchdog Control Register */

/* SPI REGISTERS */
#pragma DATA_SEG SHORT SPI
extern volatile char SPIDR;			/* SPI Data	register	*/
extern volatile char SPICR;			/* SPI control register	*/
extern volatile char SPICSR;			/* SPI control status register	*/

/* PWM ART REGISTERS */
#pragma DATA_SEG SHORT ART
extern volatile char PWMDCR1;			/* PWM AR Timer Duty Cycle Register 1	*/
extern volatile char PWMDCR0;			/* PWM AR Timer Duty Cycle Register 0	*/
extern volatile char PWMCR;				/* PWM AR Timer Control Register	*/
	#define		EXCL		0x80
	#define		CC2			0x40
	#define		CC1			0x20
	#define		CC0			0x10
	#define		TCE			0x08
	#define		FCRL		0x04
	#define		OIE			0x02
	#define		OVF			0x01
extern volatile char ARTCSR;			/* Auto Reload Timer Control/Status Register	*/
extern volatile char ARTCAR;			/* Auto Reload Timer Counter Access Register	*/
extern volatile char ARTARR;			/* Auto Reload Timer Auto Reload Register	*/
extern volatile char ARTICCSR;			/* ART Input Capture Control/Status Register	*/
extern volatile char ARTICR1;			/* ART Input Capture Register 1	*/
extern volatile char ARTICR2;			/* ART Input Capture Register 2	*/

/* USB REGISTERS */
#pragma DATA_SEG SHORT USB
extern volatile char USBISTR;			/* USB Interrupt Status register	*/
extern volatile char USBIMR;			/* USB Interrupt Mask register	*/
extern volatile char USBCTLR;			/* USB Control register	*/
extern volatile char DADDR;			/* Device Address register	*/
extern volatile char USBSR;			/* USB Status register	*/
extern volatile char EP0R;				/* Endpoint 0 Register */
extern volatile char CNT0RXR;			/* CouNT endp. 0 Reception Register */
extern volatile char CNT0TXR;			/* CouNT endp. 0 Reception Register */
extern volatile char EP1TXR;			/* Endpoint 1 Transmission Register */
extern volatile char CNT1TXR;			/* CouNT endp. 1 Transmission Register */
extern volatile char EP2RXR;			/* Endpoint 2 Reception Register */
extern volatile char CNT2RXR;			/* CouNT endp. 2 Reception Register */
extern volatile char EP2TXR;			/* Endpoint 2 Transmission Register */
extern volatile char CNT2TXR;			/* CouNT endp. 2 Reception Register */
extern volatile char EP3TXR;			/* Endpoint 3 Transmission Register */
extern volatile char CNT3TXR;			/* CouNT endp. 3 Transmission Register */
extern volatile char EP4TXR;			/* Endpoint 4 Transmission Register */
extern volatile char CNT4TXR;			/* CouNT endp. 4 Transmission Register */
extern volatile char EP5TXR;			/* Endpoint 5 Transmission Register */
extern volatile char CNT5TXR;			/* CouNT endp. 5 Transmission Register */
extern volatile char ERRSR;

/* SW ITC */
#pragma DATA_SEG SHORT ITC
extern volatile char ITSPR0;			/* Interrupt Software Priority Register 0 */
extern volatile char ITSPR1;			/* Interrupt Software Priority Register 1 */
extern volatile char ITSPR2;			/* Interrupt Software Priority Register 2 */
extern volatile char ITSPR3;			/* Interrupt Software Priority Register 3 */

/* TBU */
#pragma DATA_SEG SHORT TBU
extern volatile char TBUCV;
extern volatile char TBUCSR;

/* FLASH */
#pragma DATA_SEG SHORT FLASH
extern volatile char FCSR;

/* HUB REGISTERS */
#pragma DATA_SEG SHORT HUB
extern volatile char HUBCR;			/* HUB Control register	*/
	#define		PWREF		0x80
	#define		MPWREF		0x40
	#define		OVCEF		0x08
	#define		BUSSELF		0x04
	#define		PWRC		0x02
	#define		RST			0x01
extern volatile char HUBVIDLR;			/* HUB Vendor ID Low register	*/
extern volatile char HUBVIDHR;			/* HUB Vendor ID High register	*/
extern volatile char HUBPIDLR;			/* HUB Product ID Low register	*/
extern volatile char HUBPIDHR;			/* HUB Product ID High register	*/

/* ICD REGISTERS */
#pragma DATA_SEG SHORT ICD
extern volatile char ICDCR;			/* In Circuit Debug Control register	*/
extern volatile char ICDSR;			/* ICD Status register	*/
extern volatile char ICDBK1H;			/* ICD Breakpoint 1 MSB	*/
extern volatile char ICDBK1L;			/* ICD Breakpoint 1 LSB	*/
extern volatile char ICDBK2H;			/* ICD Breakpoint 2 MSB	*/
extern volatile char ICDBK2L;			/* ICD Breakpoint 2 LSB	*/


#pragma DATA_SEG EP0_OUT
extern volatile char EP0_OUT[8];

#pragma DATA_SEG EP0_IN
extern volatile char EP0_IN[8];

#pragma DATA_SEG EP1_IN
extern volatile char EP1_IN[8];

#pragma DATA_SEG EP2_OUT
extern volatile char EP2_OUT[64];

#pragma DATA_SEG EP2_IN
extern volatile char EP2_IN[64];

#pragma DATA_SEG EP3_IN
extern volatile char EP3_IN[8];

#pragma DATA_SEG EP4_IN
extern volatile char EP4_IN[8];

#pragma DATA_SEG EP5_IN
extern volatile char EP5_IN[8];

#endif

/*** (c) 2001   STMicroelectronics ****************** END OF FILE ***/