/**************** (c) 2001  STMicroelectronics ********************************

NAME:		descriptor.c
PROJECT:	Sample descriptor for ST7 USB Full Speed library
VERSION:	v 1.20
CREATION:	07/01/2002
AUTHOR:		MICROCONTROLLER DIVISION / ST Rousset

-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-

MODIFICATIONS : 

******************************************************************************/
#include "mcu_conf.h"
#include "usb_lib.h"
#include "descriptor.h"

#pragma CONST_SEG	APPLI_CONST

//USB Device Descriptor
const char Sample_DeviceDescriptor[] = 
{
	0x12,	//Descriptor length = 18
	0x01,	//Device descriptor type
	0x10,	//USB Specification v1.10 (2bytes)
	0x01,
	0x00,	//Device class
	0x00,	//Device subclass
	0x00,	//Device protocol
	MAX_PACKET_SIZE,	//Control endpoint maxpacketsize
	0x83,
	0x04,	//Vendor ID 0x0483 (2bytes)
	0x60,
	0x72,	//Product ID 0x7260 (2bytes)
	0x00,
	0x01,	//Device release number 1.00 (2bytes)
	0x01,	//Manufacturer string index
	0x02,	//Product string index
	0x03,	//Serial number string index
	0x01	//Number of configurations
};

//USB Configuration Descriptor
//Note: Contains: Configuration descriptor,	interface
//descriptor, and endpoint descriptors
const char Sample_ConfigurationDescriptor[] = 
{
	0x09,	//Configuration descriptor length = 9
	0x02,	//Configuration descriptor type
	SIZE_CONFIG_DESC,	//Total length of all descriptors (2bytes)
	0x00,	
	0x01,	//Number of interfaces
	0x01,	//Configuration value to select this configuration
	0x00,	//Configuration string index
	0x80,	//Device characteristics
	0x32,	//Device power requirements (100 mA)

	0x09,	//Interface descriptor length = 9
	0x04,	//Interface descriptor type
	0x00,	//Number of this interface
	0x00,	//Alternate setting for this interface
#if defined(MCU_ST7HUB) || defined(MCU_ST7SCR)
	0x05,	//Number of endpoints
#endif
#ifdef MCU_ST7265
	0x02,
#endif
	0x00,	//Interface class
	0x00,	//Interface subclass
	0x00,	//Interface protocol
	0x00,	//Interface string index

	0x07,	//Endpoint descriptor length = 7
	0x05,	//Endpoint descriptor type
	0x82,	//Endpoint address (IN, address 2)
	0x02,	//Bulk endpoint type
	MAX_EP2_PACKET_SIZE,	//Maximum packet size (IN report size, 2bytes)
	0x00,
	0x00,	//Polling interval in milliseconds

	0x07,	//Endpoint descriptor length = 7
	0x05,	//Endpoint descriptor type
	0x02,	//Endpoint address (OUT, address 2)
	0x02,	//Bulk endpoint type
	MAX_EP2_PACKET_SIZE,	//Maximum packet size (OUT report size, 2bytes)
	0x00,
	0x00,	 //Polling interval in milliseconds

#if defined(MCU_ST7HUB) || defined(MCU_ST7SCR)

	0x07,	//Endpoint descriptor length = 7
	0x05,	//Endpoint descriptor type
	0x83,	//Endpoint address (IN, address 2)
	0x03,	//Interrupt endpoint type
	MAX_EP3_PACKET_SIZE,	//Maximum packet size (IN report size, 2bytes)
	0x00,
	0x03,	//Polling interval in milliseconds

	0x07,	//Endpoint descriptor length = 7
	0x05,	//Endpoint descriptor type
	0x84,	//Endpoint address (IN, address 2)
	0x03,	//Interrupt endpoint type
	MAX_EP4_PACKET_SIZE,	//Maximum packet size (IN report size, 2bytes)
	0x00,
	0x04,	//Polling interval in milliseconds

	0x07,	//Endpoint descriptor length = 7
	0x05,	//Endpoint descriptor type
	0x85,	//Endpoint address (IN, address 2)
	0x03,	//Interrupt endpoint type
	MAX_EP5_PACKET_SIZE,	//Maximum packet size (IN report size, 2bytes)
	0x00,
	0x05  //Polling interval in milliseconds
#endif

};

const char Sample_StringDescriptor[] = {
	0x04,
	0x03,
// LangID: 0x0409
	0x09,
	0x04
};

const char Sample_VendorString[] = {
	SIZE_STRING_VENDOR,
	0x03,
// Manufacturer: "STMicroelectronics"
	'S',0, 'T',0, 'M',0, 'i',0, 'c',0, 'r',0, 'o',0, 'e',0,
	'l',0, 'e',0, 'c',0, 't',0, 'r',0, 'o',0, 'n',0, 'i',0,
	'c',0, 's',0
};

const char Sample_ProductString[] = {
	SIZE_STRING_PRODUCT,
	0x03,
// Product: "Sample of ST7 USB FS Library"
	'S',0, 'a',0, 'm',0, 'p',0, 'l',0, 'e',0, ' ',0, 'o',0,
	'f',0, ' ',0, 'S',0, 'T',0, '7',0, ' ',0, 'U',0, 'S',0,
	'B',0, ' ',0, 'F',0, 'S',0, ' ',0, 'L',0, 'i',0, 'b',0,
	'r',0, 'a',0, 'r',0, 'y',0
};

const char Sample_SerialString[] = {
	SIZE_STRING_SERIAL,
	0x03,
// Serial number: "07-01-2002"
	'0',0, '7',0, '-',0, '0',0, '1',0, '-',0, '2',0, '0',0,
	'0',0, '2',0
};

/**************** (c) 2001  STMicroelectronics **********************/
