/**************** (c) 2001  STMicroelectronics ********************************

NAME:		user_usb.c
PROJECT:	Sample user code for ST7 USB Full Speed library
VERSION:	v 1.20
CREATION:	07/01/2002
AUTHOR:		MICROCONTROLLER DIVISION / ST Rousset

-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-

MODIFICATIONS : 

******************************************************************************/
#include "mcu_conf.h"
#include "usb_reg.h"
#include "usb_def.h"
#include "usb_lib.h"

#include "appli.h"
#include "descriptor.h"

#pragma INTO_ROM
const unsigned char HID_Descriptor[] = "Put HID descriptor here";
#pragma INTO_ROM
const unsigned char Report_Descriptor[] = "Write Report Descriptor here";

#pragma CONST_SEG	APPLI_CONST
const ONE_DESCRIPTOR DeviceDescriptor = {
	Sample_DeviceDescriptor,
	SIZE_DEVICE_DESC	// sizeof(Sample_DeviceDescriptor)
};

const ONE_DESCRIPTOR ConfigDescriptor[1] = {
	Sample_ConfigurationDescriptor,
	SIZE_CONFIG_DESC	// sizeof(Sample_ConfigurationDescriptor)
};

const ONE_DESCRIPTOR StringDescriptor[NUM_STRING_DESC] = {
	Sample_StringDescriptor, 4,	// Index 0 must be for language ID
	Sample_VendorString,	SIZE_STRING_VENDOR,
	Sample_ProductString,	SIZE_STRING_PRODUCT,
	Sample_SerialString,	SIZE_STRING_SERIAL
};

#pragma DATA_SEG SHORT APPLI_RAM0
unsigned char MySetReport, Input_Seed;
unsigned char Report_Input[10];

#ifndef MCU_ST72651
#pragma DATA_SEG APPLI_RAM
#endif

unsigned char Report_Output1[10];
unsigned char Report_Output2[10];
unsigned char Report_Output3[10];

#pragma CODE_SEG	APPLI_CODE
/*-----------------------------------------------------------------------------
ROUTINE NAME : USER_USB_Set_Configuration
INPUT/OUTPUT : None
DESCRIPTION  : Assign configuration value sent by Host & reset Stalled EPs.
-----------------------------------------------------------------------------*/
char USER_USB_Set_Configuration(void)
{
	// Valid request in ADDRESS_STATE and CONFIGURED_STATE
	if (vUSB_Configuration == 0) {	// Device is Unconfigured
		USB_SetTxEP1Status(EP_DISABLE);
		USB_SetTxEP2Status(EP_DISABLE);
		USB_SetRxEP2Status(EP_DISABLE);

#if defined(MCU_ST7HUB) || defined(MCU_ST7SCR)

		USB_SetTxEP3Status(EP_DISABLE);
		USB_SetTxEP4Status(EP_DISABLE);
		USB_SetTxEP5Status(EP_DISABLE);
#endif

	}
	else {
		USB_SetTxEP1Status(EP_NAK);
		USB_SetRxEP2Status(EP_NAK);
		USB_SetTxEP2Status(EP_NAK);

#if defined(MCU_ST7HUB) || defined(MCU_ST7SCR)

		USB_SetTxEP3Status(EP_NAK);
		USB_SetTxEP4Status(EP_NAK);
		USB_SetTxEP5Status(EP_NAK);
#endif

	}

	return REQ_SUCCESS;
	// If the configuration is not one of the expected, you can answer an REQ_ERROR
	// The Library checks that vUSB_Configuration is not higher than MAX_NUM_CONFIG
}

/*-----------------------------------------------------------------------------
ROUTINE NAME : USER_USB_Set_Interface
INPUT/OUTPUT : None
DESCRIPTION  : Change Alternative Interface Setting
-----------------------------------------------------------------------------*/
char USER_USB_Set_Interface(void)
{
	char Interface = sUSB_vSetup.USBwIndex0;
	char Alt = sUSB_vSetup.USBwValue0;		// the alternate setting number.
	if (Interface == 0 && Alt == 0)
		return REQ_SUCCESS;
	else
		return REQ_ERROR;
}

/*-----------------------------------------------------------------------------
ROUTINE NAME : USER_USB_Get_Interface
INPUT/OUTPUT : None
DESCRIPTION  : Change Alternative Interface Setting
-----------------------------------------------------------------------------*/
char USER_USB_Get_Interface(void)				// return the alternate setting number.
{
	char Interface = sUSB_vSetup.USBwIndex0;

	if (Interface != 0)
		RequestError();
	return 0;
}


void USER_USB_Reset(void)
{
	Init_Application();

	vUSB_Num_Configuration = MAX_NUM_CONFIG;
	vUSB_Num_Interface = MAX_NUM_INTERFACE;
	vUSB_Num_Strings = NUM_STRING_DESC;
	vUSB_Interrupt_Mask = INT_MASK;

	// All endpoints are disabled by the h/w
}

/*-----------------------------------------------------------------------------
ROUTINE NAME : USB_Status_In
INPUT/OUTPUT : None
DESCRIPTION  : Application post process after status IN stage
	(if a request need to be executed after a Status_In, for example SET_ADDRESS)
-----------------------------------------------------------------------------*/
void USER_USB_Status_In(void)
{
	// No function
}

/*-----------------------------------------------------------------------------
ROUTINE NAME : USB_Status_Out
INPUT/OUTPUT : None
DESCRIPTION  : Application post process after status OUT stage 
-----------------------------------------------------------------------------*/
void USER_USB_Status_Out(void)
{
	// No function
}

void USER_USB_SOF(void)
{
	Disable_SOF();
}

void USER_USB_Suspend(void)
{
	// No function
}

void USER_USB_ESuspend(void)
{
	// No function
}

void USER_USB_WakeUp()
{
	// No function
}

void USER_USB_Setup()
{
	unsigned char count;

	vUSB_DataToCopy = (char*)0;
	MySetReport = 0;

	switch (sUSB_vSetup.USBbmRequestType) {
	case REQ_TYPE_CLASS | RECIPIENT_INTERFACE | 0x80:
		// Class request, Device->Host, Interface recipient
		if (vUSB_Configuration == 0)
			break;
		if (sUSB_vSetup.USBbRequest != HID_GET_REPORT)
			break;

		if (sUSB_vSetup.Flag & NON0_wIndex)					// Interface 0 only
			break;

		vUSB_offset = 0;
		switch (sUSB_vSetup.USBwValue1) {
		case HID_INPUT_REPORT:		// Input report
			switch (sUSB_vSetup.USBwValue0) {
			case 1:		// Input report ID 1
				vUSB_length = sizeof(Report_Input);
				break;
			case 2:		// Input report ID 2
				vUSB_length = sizeof(Report_Input) - 2;
				break;
			case 3:		// Input report ID 3
				vUSB_length = sizeof(Report_Input) - 4;
				break;
			default:	// Invalid report ID
				goto Req_Error;
			}
			if (vUSB_length > sUSB_vSetup.USBwLength)
				vUSB_length = sUSB_vSetup.USBwLength;		// Set the xmit length
			Report_Input[0] = sUSB_vSetup.USBwValue0;		// The first byte is the report ID
			for (count = 1; count < vUSB_length; count++)
				Report_Input[count] = Input_Seed++;
			vUSB_DataToCopy = Report_Input;
			return;

		case HID_OUTPUT_REPORT:		// Output report
			switch (sUSB_vSetup.USBwValue0) {
			case 1:		// Output report ID 1
				vUSB_length = sizeof(Report_Output1);
				vUSB_DataToCopy = Report_Output1;
				break;
			case 2:		// Output report ID 2
				vUSB_length = sizeof(Report_Output2);
				vUSB_DataToCopy = Report_Output2;
				break;
			case 3:		// Output report ID 3
				vUSB_length = sizeof(Report_Output3);
				vUSB_DataToCopy = Report_Output3;
				break;
			default:	// Invalid report ID
				goto Req_Error;
			}
			if (vUSB_length > sUSB_vSetup.USBwLength)
				vUSB_length = sUSB_vSetup.USBwLength;		// Set the xmit length
			return;
		}
		break;

	case REQ_TYPE_CLASS | RECIPIENT_INTERFACE:
		// Class request, Host->Device, Do not care recipient
		if (vUSB_Configuration == 0)
			break;
		if (sUSB_vSetup.USBbRequest != HID_SET_REPORT)
			break;
		if (sUSB_vSetup.Flag & NON0_wIndex)					// Interface 0 only
			break;
		if (sUSB_vSetup.USBwValue1 != HID_OUTPUT_REPORT)
			break;

		switch (sUSB_vSetup.USBwValue0) {
		case 1:		// Output report ID 1
			vUSB_length = sizeof(Report_Output1);
			MySetReport = 1;
			break;
		case 2:		// Output report ID 2
			vUSB_length = sizeof(Report_Output2);
			MySetReport = 2;
			break;
		case 3:		// Output report ID 3
			vUSB_length = sizeof(Report_Output3);
			MySetReport = 3;
			break;
		default:	// Invalid report ID
			goto Req_Error;
		}
		vUSB_offset = 0;
		if (vUSB_length > sUSB_vSetup.USBwLength)
			vUSB_length = sUSB_vSetup.USBwLength;		// Set the xmit length

		return;

	case REQ_TYPE_STANDARD | RECIPIENT_INTERFACE | 0x80:
		if (sUSB_vSetup.Flag & (NON0_wIndex | NON0_wValue0))
			break;

		vUSB_offset = 0;
		if (sUSB_vSetup.USBwValue1 == HID_HID_DESC) {
			vUSB_length = sizeof(HID_Descriptor);
			vUSB_DataToCopy = HID_Descriptor;
		}
		else if (sUSB_vSetup.USBwValue1 == HID_REPORT_DESC) {
			vUSB_length = sizeof(Report_Descriptor);
			vUSB_DataToCopy = Report_Descriptor;
		}
		else
			break;

		if (vUSB_length > sUSB_vSetup.USBwLength)
			vUSB_length = sUSB_vSetup.USBwLength;		// Set the xmit length
		return;

	default:
		break;
	}

Req_Error:
	RequestError();
}

/*-----------------------------------------------------------------------------
ROUTINE NAME : USER_USB_Set_Feature_Int
INPUT/OUTPUT : None
DESCRIPTION  : SET_FEATURE on interface.
				Check wValue and wIndex in the function
-----------------------------------------------------------------------------*/
void USER_USB_Set_Feature_Int(void)
{
	RequestError();		// Inappropriate Request. Recipient does not exist.
}

/*-----------------------------------------------------------------------------
ROUTINE NAME : USER_USB_Clear_Feature_Int
INPUT/OUTPUT : None
DESCRIPTION  : CLEAR_FEATURE on interface.
				Check wValue and wIndex in the function
-----------------------------------------------------------------------------*/
void USER_USB_Clear_Feature_Int(void)
{
	RequestError();		// Inappropriate Request. Recipient does not exist.
}

/*-----------------------------------------------------------------------------
ROUTINE NAME : USER_USB_Set_Feature_EP
INPUT/OUTPUT : None
DESCRIPTION  : Set or enable a specific feature for the specified recipient.
-----------------------------------------------------------------------------*/
void USER_USB_Set_Feature_EP(void)
{
	// No function
}

/*-----------------------------------------------------------------------------
ROUTINE NAME : USER_USB_Clear_Feature_EP
INPUT/OUTPUT : None
DESCRIPTION  : Set or enable a specific feature for the specified recipient.
-----------------------------------------------------------------------------*/
void USER_USB_Clear_Feature_EP(void)
{
	// No function
}


/*-----------------------------------------------------------------------------
ROUTINE NAME : USER_USB_CopydataOUT
INPUT/OUTPUT : Length is number of bytes to be copied. vUSB_offset is the offset
				of your data buffer
DESCRIPTION  : 
-----------------------------------------------------------------------------*/
void USER_USB_CopydataOUT(unsigned char CopyLength)
{
	unsigned char count;

	switch (MySetReport) {
	case 1:
		for (count = 0; count < CopyLength; count++)
			(Report_Output1 + vUSB_offset)[count] = EP0_OUT[count];
		return;
	case 2:
		for (count = 0; count < CopyLength; count++)
			(Report_Output2 + vUSB_offset)[count] = EP0_OUT[count];
		return;
	case 3:
		for (count = 0; count < CopyLength; count++)
			(Report_Output3 + vUSB_offset)[count] = EP0_OUT[count];
		return;
	default:
		RequestError();
	}
}

void USER_USB_CopydataIN(unsigned char CopyLength)
{
	// No function
}

#pragma DATA_SEG DEFAULT

/**************** (c) 2001  STMicroelectronics **********************/